package com.zerohighdef.geoffrey.Commands;

import com.google.gson.JsonElement;
import com.zerohighdef.geoffrey.GeoffreyMC;
import com.zerohighdef.geoffrey.Models.GeoffreyTunnel;
import com.zerohighdef.geoffrey.Objects.GeoffreyAPICallback;
import com.zerohighdef.geoffrey.Objects.GeoffreyCommand;
import com.zerohighdef.geoffrey.Objects.GeoffreyCommandError;
import org.bukkit.ChatColor;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;

import java.util.HashMap;
import java.util.Map;

public class TunnelCommand extends GeoffreyCommand {
    public TunnelCommand(GeoffreyMC plugin) {
        super(plugin);
    }

    @Override
    public boolean onCommand(CommandSender sender, Command command, String label, String[] args) {

        if (args.length > 0) {
            String playerName = args[0];
            Map<String, String> params = new HashMap<String, String>();

            params.put("player_name", playerName);
            RunCommand("tunnel", params, Method.GET, new CommandCallback(sender, playerName));
        }
        else {
            sender.sendMessage(ChatColor.RED + "You must specify a player name.");
            return false;
        }

        return true;
    }


    private class CommandCallback extends GeoffreyAPICallback {
        private String playerName;

        CommandCallback(CommandSender sender, String playerName) {
            super(sender);
            errors.put("LocationLookUpError", playerName + " has no tunnels.");
            this.playerName = playerName;
        }

        @Override
        public void invoke(String s) {
            try {
                JsonElement json = parseJSON(s);
                StringBuilder tunnelList = new StringBuilder();

                for (JsonElement jsonElement: json.getAsJsonArray()) {
                    GeoffreyTunnel tunnel = new GeoffreyTunnel(jsonElement.getAsJsonObject());
                    tunnelList.append(tunnel.getLocationName());
                    tunnelList.append(": ");
                    tunnelList.append(tunnel.getTunnelLocationString());
                    tunnelList.append("\n");
                }

                String msg =  ChatColor.BOLD + playerName + " has the following tunnels:\n" + ChatColor.RESET + tunnelList.toString();
                commandSender.sendMessage(ChatColor.GREEN + msg);
            }
            catch (GeoffreyCommandError e) {
                return;
            }
        }
    }
}
